@@ -1,6 +1,6 @@
 package Modern::Perl;
 # ABSTRACT: enable all of the features of Modern Perl with one import
-$Modern::Perl::VERSION = '1.20240115';
+$Modern::Perl::VERSION = '1.20240120';
 use 5.010_000;
 
 use strict;
@@ -27,6 +27,11 @@ sub VERSION {
     return $default;
 }
 
+my $unimport_tag;
+BEGIN {
+    $unimport_tag = $] > 5.015 ? ':all' : ':5.10';
+}
+
 sub import {
     my ($class, $date) = @_;
     $date = $wanted_date unless defined $date;
@@ -36,7 +41,7 @@ sub import {
 
     warnings->import;
     strict->import;
-    feature->unimport( ':all' );
+    feature->unimport( $unimport_tag );
     feature->import( $feature_tag );
 
     if ($feature_tag ge ':5.34') {
@@ -106,7 +111,7 @@ Modern::Perl - enable all of the features of Modern Perl with one import
 
 =head1 VERSION
 
-version 1.20240115
+version 1.20240120
 
 =head1 SYNOPSIS
 
@@ -275,8 +280,8 @@ Damian Conway (inspiration from L<Toolkit>), Florian Ragwitz
 (L<B::Hooks::Parser>, so I didn't have to write it myself), chocolateboy (for
 suggesting that I don't even need L<B::Hooks::Parser>), Damien Learns Perl,
 David Moreno, Evan Carroll, Elliot Shank, Andreas König, Father Chrysostomos,
-Gryphon Shafer, and Norbert E. Grüner for reporting bugs, filing patches, and
-requesting features.
+Gryphon Shafer, Norbert E. Grüner, and Slaven Rezic for reporting bugs, filing
+patches, and requesting features.
 
 =head1 AUTHOR
 
